@@ -31,14 +31,14 @@ LOCALE = "en"
 
 prefix_dir = Path(sys.prefix)
 if jlab_dev_mode:
-    jlab_dir = Path(jupyterlab.__file__).parent.parent / "dev_mode"
+    jlab_dir = Path(jupyterlab.__file__).parents[1] / "dev_mode"
 else:
     jlab_dir = prefix_dir / "share" / "jupyter" / "lab"
 
 
 def init_router(router, redirect_after_root):
     extensions_dir = prefix_dir / "share" / "jupyter" / "labextensions"
-    federated_extensions, _ = get_federated_extensions(extensions_dir)
+    federated_extensions, disabled_extensions = get_federated_extensions(extensions_dir)
 
     for ext in federated_extensions:
         name = ext["name"]
@@ -83,6 +83,10 @@ def init_router(router, redirect_after_root):
             "allowed_extensions": [],
         }
 
+    @router.get("/lab/api/extensions")
+    async def get_extensions(user: User = Depends(current_user())):
+        return federated_extensions
+
     @router.get("/lab/api/translations/")
     async def get_translations_(
         frontend_config=Depends(get_frontend_config),
